# steamCloudSaveDownloader
Download Save on Steam Cloud

## Early Stage Prototype: DO NOT USE


git hook to auto update version
docker puid pgid
docker mountable cron

Logo, badges

Help does not show full msg
Disclaimer: Not affiliated with steam

### Show database mode

### Running lock file to prevent re execute for cron

### DOcker
Specify CronJob

### Windows/Mac Version

### External Scheduler

### CI
- Gen executable for linux/windows
- Upload to PyPI
- Update dockerhub

### Misc
- Banners

### Logger

### Config Generator

### Remove DB in Storage Class

### Detect not login page

### Daylight saving time

### Move to milestone

### Docker auto pip update

### Tag

### Python Checker

### Special thanks: beta tester

### Windows Scheduler

### Unit tests

### Use file name + hashing instead of full path

### Organizr
